=== modified file 'bzrlib/tests/test_urlutils.py'
--- bzrlib/tests/test_urlutils.py	2006-06-30 15:32:22 +0000
+++ bzrlib/tests/test_urlutils.py	2006-07-03 18:19:49 +0000
@@ -19,9 +19,9 @@
 import os
 import sys
 
+from bzrlib import osutils, urlutils
 import bzrlib
 from bzrlib.errors import InvalidURL, InvalidURLJoin
-import bzrlib.urlutils as urlutils
 from bzrlib.tests import TestCaseInTempDir, TestCase, TestSkipped
 
 
@@ -464,3 +464,33 @@
         test('http://host/', 'http://host', 'http://host/')
         #test('.', 'http://host/', 'http://host')
         test('http://host', 'http://host/', 'http://host')
+
+
+class TestCwdToURL(TestCaseInTempDir):
+    """Test that local_path_to_url works base on the cwd"""
+
+    def test_dot(self):
+        # This test will fail if getcwd is not ascii
+        cwd = osutils.getcwd()
+        try:
+            cwd = cwd.encode('ascii')
+        except UnicodeError:
+            raise TestSkipped('test must be run in an ASCII directory')
+
+        url = urlutils.local_path_to_url('.')
+        self.assertEndsWith(url, cwd)
+
+    def test_non_ascii(self):
+        try:
+            os.mkdir(u'dod\xe9')
+        except UnicodeError:
+            raise TestSkipped('cannot create unicode directory')
+
+        os.chdir(u'dod\xe9')
+
+        # On Mac OSX this directory is actually: 
+        #   u'/dode\u0301' => '/dode\xcc\x81
+        # but we should normalize it back to 
+        #   u'/dod\xe9' => '/dod\xc3\xa9'
+        url = urlutils.local_path_to_url('.')
+        self.assertEndsWith(url, '/dod%C3%A9')

